# Self Data Grandlyon Documentation

## Install dependencies

    pip install -r  ./requirements/docs.txt

## Commands

- `mkdocs serve` - Start the live-reloading docs server.
- `mkdocs build` - Build the documentation site.
- `mkdocs help` - Print this help message.

## Files hierarchy

  When adding new pages, add it respectively to the mkdocs.yml:

nav:
  - Home:
      - Getting started: index.md
      - Additional Ressources: external_doc.md
  - Easy Cozy:
      - Introduction: easycozy/index.md
      - Configuration: easycozy/config.md
      - Commands: easycozy/commands.md
      - Known errors: easycozy/known_errors.md
      - Scripts: easycozy/scripts.md
      - Tips: easycozy/tips.md
  - Ecolyo:
      - Introduction: ecolyo/index.md
      - Getting started:
          - Setup your environment: ecolyo/getting_started/setup_your_environment.md
          - Launch the application on local: ecolyo/getting_started/launch_local_application.md
          - Launch a konnector on local: ecolyo/getting_started/launch_local_konnector.md
      - Project Architecture:
          - Architecture: ecolyo/project_architecture/architecture.md
          - Libraries: ecolyo/project_architecture/libraries.md
          - Environments: ecolyo/project_architecture/environments.md
          - Doctypes: ecolyo/project_architecture/doctypes.md
          - Remote Doctypes: ecolyo/project_architecture/remote_doctypes.md
      - Application:
          - Deploy: ecolyo/application/deploy.md
          - Description: ecolyo/application/description.md
          - Gitflow: ecolyo/application/gitflow.md
          - Mail: ecolyo/application/mail.md
          - Redux: ecolyo/application/redux.md
          - Release: ecolyo/application/release.md
          - Scaffolding: ecolyo/application/scaffolding.md
      - Services:
          - Description: ecolyo/services/index.md
          - Monthly report notification: ecolyo/services/monthly_report_notification.md
          - Aggregator usage events: ecolyo/services/aggregator_usage_events.md
          - Consumption Alert: ecolyo/services/consumption_alert.md
          - Enedis Halfhour Monthly Analysis: ecolyo/services/enedis_halfhour_monthly_analysis.md
      - Functionalities:
          - Analysis: ecolyo/functionalities/analysis.md
          - Challenge: ecolyo/functionalities/challenge.md
          - Consumption: ecolyo/functionalities/consumption.md
          - Dacc: ecolyo/functionalities/dacc.md
          - Ecogesture: ecolyo/functionalities/ecogesture.md
          - Feedback: ecolyo/functionalities/feedback.md
          - Initialization: ecolyo/functionalities/initialization.md
          - Matomo: ecolyo/functionalities/matomo.md
          - Onboarding: ecolyo/functionalities/onboarding.md
          - Price Calculation: ecolyo/functionalities/prices_calculation.md
          - Profile Type: ecolyo/functionalities/profile_type.md
          - Terms: ecolyo/functionalities/terms.md
          - Usage events tracking: ecolyo/functionalities/usage_events_tracking.md
      - Ecolyo-Agent:
          - Introduction: ecolyo/ecolyo-agent/introduction.md
          - Getting started:
              - Setup your environment: ecolyo/ecolyo-agent/getting_started/setup_your_environment.md
              - Launch the application on local: ecolyo/ecolyo-agent/getting_started/launch_local_application.md
              - Libraries: ecolyo/ecolyo-agent/getting_started/libraries.md
          - Functionalities:
              - General: ecolyo/ecolyo-agent/functionalities/general.md
              - Authentication: ecolyo/ecolyo-agent/functionalities/authentication.md
              - Routes: ecolyo/ecolyo-agent/functionalities/routes.md
          - Development:
              - Deploy: ecolyo/ecolyo-agent/development/deploy.md
              - Handle assets: ecolyo/ecolyo-agent/development/handle_assets.md
              - Backup: ecolyo/ecolyo-agent/development/backup.md
  - Pilote:
      - Pilote - TS - Back:
          - Index: pilote/Pilote - TS - Back/index.md
          - Application:
              - Deploy: pilote/Pilote - TS - Back/application/deploy.md
          - Functionalities:
              - Routes: pilote/Pilote - TS - Back/functionalities/routes.md
          - Getting Started:
              - Launch the application on local: pilote/Pilote - TS - Back/getting_started/launch_local_application.md
              - Setup your environment: pilote/Pilote - TS - Back/getting_started/setup_your_environment.md
          - Project Architecture: pilote/Pilote - TS - Back/project_architecture/architecture.md
      - Pilote - TS - Front:
          - Index: pilote/Pilote - TS - Front/index.md
          - Application:
              - Deploy: pilote/Pilote - TS - Front/application/deploy.md
          - Functionalities:
              - Routes: pilote/Pilote - TS - Front/functionalities/functions.md
          - Getting Started:
              - Launch the application on local: pilote/Pilote - TS - Front/getting_started/launch_local_application.md
      - Pilote - Usager:
          - Application:
              - Deploy: pilote/Pilote - Usager/application/deploy.md
              - Doctypes: pilote/Pilote - Usager/application/doctypes.md
              - Gitflow: pilote/Pilote - Usager/application/gitflow.md
              - Scaffolding: pilote/Pilote - Usager/application/scaffolding.md
              - Services: pilote/Pilote - Usager/application/services.md
              - Store: pilote/Pilote - Usager/application/store.md
          - Functionalities:
              - Appointments: pilote/Pilote - Usager/functionalities/appointments.md
              - Contact: pilote/Pilote - Usager/functionalities/contact.md
              - Document: pilote/Pilote - Usager/functionalities/document.md
              - Settings: pilote/Pilote - Usager/functionalities/setting.md
              - Cozy Registry: pilote/Pilote - Usager/functionalities/cozy-registry.md
          - Getting Started:
              - Setup your environment: ecolyo/getting_started/setup_your_environment.md
              - Launch local application: pilote/Pilote - Usager/getting_started/launch_local_application.md
              - Launch local doctypes: pilote/Pilote - Usager/getting_started/launch_local_doctypes.md
              - Launch local services: pilote/Pilote - Usager/getting_started/launch_local_services.md
  - Konnectors:
      - Introduction: konnectors/index.md
      - Enedis: konnectors/enedis.md
      - Enedis: konnectors/enedis-sge.md
      - GRDF: konnectors/grdf.md
      - Eau du Grand Lyon: konnectors/egl.md
  - Proxy:
      - Description: proxy/description.md
      - Monitoring: proxy/monitoring.md
      - Use cases:
          - Enedis: proxy/use_cases/enedis.md
          - Grdf Adict: proxy/use_cases/grdfadict.md